# Changelog

<!--next-version-placeholder-->

## v0.6.3 (2022-08-15)
### Fix
* Add a space ([`fd182ac`](https://github.com/harvey251/pydantic-lambda-handler/commit/fd182acd14017b320d480a5cb8b7a6218501ac42))

## v0.6.2 (2022-08-15)
### Fix
* Add a space ([`fd182ac`](https://github.com/harvey251/pydantic-lambda-handler/commit/fd182acd14017b320d480a5cb8b7a6218501ac42))
* Add a space ([`1cb8651`](https://github.com/harvey251/pydantic-lambda-handler/commit/1cb8651e67a116ff4e164bda94168dbd64ac620e))

## v0.6.1 (2022-08-15)
### Fix
* Add a space ([`8e4a006`](https://github.com/harvey251/pydantic-lambda-handler/commit/8e4a0066e649aa7ea126e9ce9ba53cee3709b46f))

## v0.6.0 (2022-08-15)
### Feature
* Add request body to open api spec ([#35](https://github.com/harvey251/pydantic-lambda-handler/issues/35)) ([`47891da`](https://github.com/harvey251/pydantic-lambda-handler/commit/47891da9ec80bfe312dc8489b2565333f9e9ba3b))

## v0.5.1 (2022-08-14)
### Fix
* Merge post and get ([#33](https://github.com/harvey251/pydantic-lambda-handler/issues/33)) ([`f4cff6f`](https://github.com/harvey251/pydantic-lambda-handler/commit/f4cff6f68ad1185f120cbd542aa946cf128a6a75))

## v0.5.0 (2022-08-14)
### Feature
* Add post data ([#32](https://github.com/harvey251/pydantic-lambda-handler/issues/32)) ([`544b1e1`](https://github.com/harvey251/pydantic-lambda-handler/commit/544b1e16882de23c6ddd9d791dc7255ac9d46650))

## v0.4.1 (2022-08-12)
### Fix
* Add pydantic core test ([#31](https://github.com/harvey251/pydantic-lambda-handler/issues/31)) ([`368deae`](https://github.com/harvey251/pydantic-lambda-handler/commit/368deae1976862a975bafaf23b18333e1ac3b68a))

## v0.4.0 (2022-08-12)
### Feature
* Add query ([#30](https://github.com/harvey251/pydantic-lambda-handler/issues/30)) ([`fcfa161`](https://github.com/harvey251/pydantic-lambda-handler/commit/fcfa161d73cf78de5716a3449ac3ac33a84908c2))

## v0.3.1 (2022-08-11)
### Fix
* Add check for redeclaration of path ([#29](https://github.com/harvey251/pydantic-lambda-handler/issues/29)) ([`a9671c6`](https://github.com/harvey251/pydantic-lambda-handler/commit/a9671c6f4c5ca6d61032e6ebbed986df3dae536b))

## v0.3.0 (2022-08-11)
### Feature
* Move gen open api spec into a hook ([#28](https://github.com/harvey251/pydantic-lambda-handler/issues/28)) ([`a2e34b8`](https://github.com/harvey251/pydantic-lambda-handler/commit/a2e34b8736a6303009a7d8ea64cefa2afd3a915a))

## v0.2.0 (2022-07-31)
### Feature
* Add task to deploy ([#23](https://github.com/harvey251/pydantic-lambda-handler/issues/23)) ([`ea67f71`](https://github.com/harvey251/pydantic-lambda-handler/commit/ea67f71001552b4eeff8d08a9379c7e271be7921))

### Documentation
* Improve Vision statement ([#22](https://github.com/harvey251/pydantic-lambda-handler/issues/22)) ([`af7c95f`](https://github.com/harvey251/pydantic-lambda-handler/commit/af7c95f73b3d71b56948b50ddacf5aaa52e7ebd7))

## v0.1.0 (2022-07-13)
### Feature
* Add open api spec ([`a6b5ff9`](https://github.com/harvey251/pydantic-lambda-handler/commit/a6b5ff96bf4695c6dd9ee2e73492a97134323361))
* Add error message with invalid params ([#8](https://github.com/harvey251/pydantic-lambda-handler/issues/8)) ([`0ad9ff1`](https://github.com/harvey251/pydantic-lambda-handler/commit/0ad9ff13e512a0904624a8f806cb787393040650))
* Add open api spec ([#7](https://github.com/harvey251/pydantic-lambda-handler/issues/7)) ([`82db24b`](https://github.com/harvey251/pydantic-lambda-handler/commit/82db24b23025939188ee6ed728bbc31d28552124))

### Fix
* Release on main ([#12](https://github.com/harvey251/pydantic-lambda-handler/issues/12)) ([`c142360`](https://github.com/harvey251/pydantic-lambda-handler/commit/c142360be3c88a568969625ae5c08d7daf83b8ba))
* Add default required values for open api spec ([#11](https://github.com/harvey251/pydantic-lambda-handler/issues/11)) ([`e380eb9`](https://github.com/harvey251/pydantic-lambda-handler/commit/e380eb90ce5c3a21b9790742497ec88a8805ad40))
* Add init ([#10](https://github.com/harvey251/pydantic-lambda-handler/issues/10)) ([`c20f3bb`](https://github.com/harvey251/pydantic-lambda-handler/commit/c20f3bb437e9ac38e4e50c89981c32afbd44aedb))
